API Reference
=============

Dekad
-----

.. autoclass:: kalendar.Dekad
    :members:
    :undoc-members:
    :special-members: __add__, __sub__

Pentad
-----

.. autoclass:: kalendar.Pentad
    :members:
    :undoc-members:
    :special-members: __add__, __sub__
